@@ -567,9 +567,33 @@ class Cursor(Base):
             return CURSOR_LIMIT
         if limit < 1:
             return 1
-
         return limit
 
+class CursorExt(Cursor):
+    serial = Attribute(types=str, coerce=str)
+    direction = Attribute(types=str, required=True, default='DESC')
+
+    def __init__(self, row = None, **kw):
+        if row is None:
+            row = {}
+        if isinstance(row, CursorExt):
+            row = row.pure_python()
+
+        if isinstance(row, str):
+            data = unpack(TOKEN, row)
+
+            if data is None:
+                row = {}
+            elif isinstance(data, dict):
+                row = data.get('cursor', {})
+            else:
+                row = {}
+
+        row = copy.copy(row)
+        row['limit'] = self._force_limit(row.get('limit', None))
+
+        super().__init__(row, **kw)
+
 
 class BaseModel(Base):
     """ Base model """
@@ -630,7 +654,7 @@ class BaseModel(Base):
             subpath += '.sqlt'
         return os.path.join(cls.sqlbase(), subpath)
 
-    async def save(self, db=None, **kw):
+    async def save(self, db=None, by='id', **kw):
         db = self.get_db(db)
 
         for k, v in self.meta.fields.items():
@@ -643,7 +667,7 @@ class BaseModel(Base):
 
         sql, args = sqlt('save.sqlt', {
             **kw,
-            'key_def': 'id',
+            'key_def': (by,) if isinstance(by, str) else by,
             'key_tuple': self.get_key(),
             'table': self.meta.table,
             'this': self,
@@ -666,14 +690,14 @@ class BaseModel(Base):
         self.rehashed('-clean')
         return self
 
-    async def rm(self, db=None, **kw):
+    async def rm(self, db=None, by='id', **kw):
         """ Remove """
 
         db = self.get_db(db)
 
         sql, args = sqlt('rm.sqlt', {
             **kw,
-            'key_def': ['id'],
+            'key_def': (by,) if isinstance(by, str) else by,
             'key_tuple': self.get_key(),
             'table': self.meta.table,
             'this': self,
@@ -697,7 +721,15 @@ class BaseModel(Base):
         return self
 
     @classmethod
-    async def get(cls, ids=None, limit=None, offset=None, cursor=None, **kw):
+    async def get(
+        cls,
+        ids=None,
+        limit=None,
+        offset=None,
+        cursor=None,
+        by='id',
+        **kw,
+    ):
         """ Get instances of the object """
 
         db = cls.get_db()
@@ -712,31 +744,35 @@ class BaseModel(Base):
             kw['sort'] = [kw['sort']]
 
         if ids:
-            tmp = 'load.sqlt'
+            tmp = 'get.sqlt'
             kw = {
                 **kw,
-                'key_def': ('id',),
+                'key_def': (by,) if isinstance(by, str) else by,
                 'key': ids,
                 'key_tuple': ids if isinstance(ids, (list, tuple)) else [ids],
                 'class': cls,
             }
 
-        elif offset is not None:
-            tmp = 'list.sqlt'
+        elif offset is not None or by == 'pager':
+            tmp = 'pager.sqlt'
             pager = Pager(offset=offset, limit=limit, **kw)
             kw['pager'] = pager
 
+        elif cursor is not None or by == 'cursor':
+            tmp = 'cursor.sqlt'
+            cursor = CursorExt(cursor or kw)
+            kw['cursor'] = cursor
+
         else:
             tmp = 'full.sqlt'
-            cursor = Cursor(kw)
-            kw['cursor'] = cursor
+            cursor = CursorExt(kw)
 
         sql, args = sqlt(tmp, kw)
 
         async with dbh(**db) as conn:
             data = await conn.fetch(sql, *args)
 
-        if ids:
+        if tmp == 'get.sqlt':
             if not data:
                 return None
 
@@ -746,7 +782,7 @@ class BaseModel(Base):
 
             return data
 
-        if offset is not None:
+        if tmp == 'pager.sqlt':
             if not pager.disabled:
                 if len(data) <= pager.limit:
                     pager.latest = True
@@ -762,6 +798,8 @@ class BaseModel(Base):
             return pager.list
 
         cursor.list = [cls(x) for x in data]
+        if cursor.list:
+            cursor.serial = str(cursor.list[-1].id)
 
         if isinstance(db, dict) and 'shard' in db:
             for item in cursor.list:
